@@ -107,15 +107,12 @@ int window_get_arg(context_t *context, int min_arg, int window_arg_pos,
             context->argc, min_arg);
     return False;
   } else if (context->argc == min_arg) {
-    //fprintf(stderr, "Using default arg\n");
     /* nothing, keep default */
   } else if (context->argc > min_arg) {
     if (is_command(context->argv[min_arg])) {
-      //fprintf(stderr, "arg is command, using default\n");
       /* keep default */
     } else {
       /* got enough args, let's use the window you asked for */
-      //fprintf(stderr, "got enough args\n");
       *window_arg = context->argv[window_arg_pos];
       consume_args(context, 1);
     }
@@ -223,6 +220,7 @@ struct dispatch {
   { "getactivewindow", cmd_getactivewindow, },
   { "getwindowfocus", cmd_getwindowfocus, },
   { "getwindowname", cmd_getwindowname, },
+  { "getwindowclassname", cmd_getwindowclassname},
   { "getwindowpid", cmd_getwindowpid, },
   { "getwindowgeometry", cmd_getwindowgeometry, },
   { "getdisplaygeometry", cmd_get_display_geometry, },
@@ -251,12 +249,14 @@ struct dispatch {
   { "windowfocus", cmd_windowfocus, },
   { "windowkill", cmd_windowkill, },
   { "windowclose", cmd_windowclose, },
+  { "windowquit", cmd_windowquit, },
   { "windowmap", cmd_windowmap, },
   { "windowminimize", cmd_windowminimize, },
   { "windowmove", cmd_windowmove, },
   { "windowraise", cmd_windowraise, },
   { "windowreparent", cmd_windowreparent, },
   { "windowsize", cmd_windowsize, },
+  { "windowstate", cmd_windowstate, },
   { "windowunmap", cmd_windowunmap, },
 
   { "set_num_desktops", cmd_set_num_desktops, },
@@ -359,7 +359,7 @@ int script_main(int argc, char **argv) {
   /* read input... */
   int pos;
   char *token;
-  int result;
+  int result = XDO_SUCCESS;
 
   while (fgets(buffer, 4096, input) != NULL) {
     char *line = buffer;
@@ -451,7 +451,7 @@ int script_main(int argc, char **argv) {
         script_argv[script_argc] = (char *) calloc(strlen(token) + 1, sizeof(char));
 
         //printf("arg %d: %s\n", script_argc, token);
-        strncpy(script_argv[script_argc], token, strlen(token)+1);      
+        strcpy(script_argv[script_argc], token);      
         script_argc++;
       }
       
@@ -520,10 +520,14 @@ int args_main(int argc, char **argv) {
     cmd_help(NULL);
     exit(1);
   }
-  
-  //for(i = 0; i<argc; i++) {
-    //fprintf(stderr, "argv[%d] = \"%s\"\n", i, argv[i]);
-  //}
+
+  if (!strcasecmp(argv[1], "help")) {
+    cmd_help(NULL);
+    exit(EXIT_SUCCESS);
+  } else if (!strcasecmp(argv[1], "version")) {
+    cmd_version(NULL);
+    exit(EXIT_SUCCESS);
+  }
 
   while ((opt = getopt_long_only(argc, argv, "++hv", long_options, &option_index)) != -1) {
     switch (opt) {
@@ -551,7 +555,7 @@ int args_main(int argc, char **argv) {
   context.debug = (getenv("DEBUG") != NULL);
 
   if (context.xdo == NULL) {
-    fprintf(stderr, "Failed creating new xdo instance\n");
+    fprintf(stderr, "Failed creating new xdo instance.\n");
     return 1;
   }
   context.xdo->debug = context.debug;
